Use &Path instead of a generic P: AsRef<Path> here,
because object safety requirements, it is especially useful, when
you want to store multiple dyn FileSystem in a Vec or use a ResolverGeneric<Fs> in
napi env.
Use &Path instead of a generic P: AsRef<Path> here,
because object safety requirements, it is especially useful, when
you want to store multiple dyn FileSystem in a Vec or use a ResolverGeneric<Fs> in
napi env.
Use &Path instead of a generic P: AsRef<Path> here,
because object safety requirements, it is especially useful, when
you want to store multiple dyn FileSystem in a Vec or use a ResolverGeneric<Fs> in
napi env.
Use &Path instead of a generic P: AsRef<Path> here,
because object safety requirements, it is especially useful, when
you want to store multiple dyn FileSystem in a Vec or use a ResolverGeneric<Fs> in
napi env.